#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

//=====================================================================================================
//   OpenSource code distributed under the CDDL v1.0 (http://www.opensource.org/licenses/cddl1.php)
//=====================================================================================================
//
//  Enjoy this OpenSource NinjaScript v6.0 indicator!  May it help bring you great amounts of profit!

//  If you have profited from this code, then please consider a suitable donation of any amount to its 
//  Initial Developer and/or other Contributors.  Contact information given below.

//  Also, feel free to email enhancement suggestions to:
//          Initial Developer:  SBG Trading Corp., Ben Letto, sbgtrading@yahoo.com February 2, 2008
//
//=====================================================================================================

namespace NinjaTrader.Indicator
{
    /// <summary>
    /// 
    /// </summary>
    [Description("")]
    [Gui.Design.DisplayName("HiLoActivator")]
    public class HiLoActivator : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int length = 20; // Default setting for Length
        // User defined variables (add any user defined variables below)
			private double Havg,Lavg;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.PaleTurquoise), PlotStyle.Line, "B"));
            Add(new Plot(Color.FromKnownColor(KnownColor.HotPink), PlotStyle.Line, "S"));
            CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if(CurrentBar<length+1) return;
			Havg = SMA(High,length)[1];
			Lavg = SMA(Low,length)[1];
			if(Input[0]<Lavg)
			{	B.Set(Lavg);
            	S.Set(Havg);
			}
			if(Input[0]>Havg)
			{	B.Set(Havg);
            	S.Set(Lavg);
			}
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries B
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries S
        {
            get { return Values[1]; }
        }

        [Description("SMA period")]
        [Category("Parameters")]
        public int Length
        {
            get { return length; }
            set { length = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private HiLoActivator[] cacheHiLoActivator = null;

        private static HiLoActivator checkHiLoActivator = new HiLoActivator();

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public HiLoActivator HiLoActivator(int length)
        {
            return HiLoActivator(Input, length);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public HiLoActivator HiLoActivator(Data.IDataSeries input, int length)
        {
            checkHiLoActivator.Length = length;
            length = checkHiLoActivator.Length;

            if (cacheHiLoActivator != null)
                for (int idx = 0; idx < cacheHiLoActivator.Length; idx++)
                    if (cacheHiLoActivator[idx].Length == length && cacheHiLoActivator[idx].EqualsInput(input))
                        return cacheHiLoActivator[idx];

            HiLoActivator indicator = new HiLoActivator();
            indicator.SetUp();
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Length = length;

            HiLoActivator[] tmp = new HiLoActivator[cacheHiLoActivator == null ? 1 : cacheHiLoActivator.Length + 1];
            if (cacheHiLoActivator != null)
                cacheHiLoActivator.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheHiLoActivator = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.HiLoActivator HiLoActivator(int length)
        {
            return _indicator.HiLoActivator(Input, length);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.HiLoActivator HiLoActivator(Data.IDataSeries input, int length)
        {
            return _indicator.HiLoActivator(input, length);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.HiLoActivator HiLoActivator(int length)
        {
            return _indicator.HiLoActivator(Input, length);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.HiLoActivator HiLoActivator(Data.IDataSeries input, int length)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.HiLoActivator(input, length);
        }

    }
}
#endregion
